@@ -34,12 +34,22 @@ class Not(Comparator):
 
     def calculate(self, field_name, field_type, *args, **kwargs):
         if isinstance(field_type, bool):
-            if self.value:
-                operator = 'is'
-            else:
-                operator = 'not'
+            operator = 'is not'
 
         else:
             operator = '!='
 
         return self.TEMPLATE.format(field_name=field_name, operator=operator, value=self.value)
+
+
+class Equal(Comparator):
+    TEMPLATE = '{field_name} {operator} {value}'
+
+    def calculate(self, field_name, field_type, *args, **kwargs):
+        if isinstance(field_type, bool):
+            operator = 'is'
+
+        else:
+            operator = '='
+
+        return self.TEMPLATE.format(field_name=field_name, operator=operator, value=self.value)
