@@ -1,10 +1,11 @@
 import inspect
 
-from jija_orm import fields
+
 from jija_orm.executors import query, executors, templates
 
 
 class Model:
+    from jija_orm import fields
     id = fields.IntegerField(pk=True)
 
     manager = query.QueryManager
@@ -12,12 +13,16 @@ class Model:
     def __init__(self, *, from_query=False, **kwargs):
         self.__from_query = from_query
         self.__state = {}
-        for kwarg in kwargs:
-            if hasattr(self, kwarg):
-                setattr(self, kwarg, kwargs[kwarg])
-                self.__state[kwarg] = kwargs[kwarg]
-            else:
-                raise NotImplementedError()
+
+        for field in self.get_fields():
+            value = kwargs.get(field)
+            self.__state[field] = value
+            setattr(self, field, value)
+
+        for constraint in self.get_constraints():
+            value = kwargs.get(constraint) or kwargs.get(f'{constraint}_id')
+            self.__state[constraint] = value
+            setattr(self, constraint, value)
 
     @classmethod
     def init_managers(cls, real_class=None):
@@ -33,6 +38,7 @@ class Model:
         model_fields = {}
 
         for name, attr in cls.__dict__.items():
+            from jija_orm import fields
             if isinstance(attr, fields.Field):
                 model_fields[name] = attr
 
@@ -42,10 +48,11 @@ class Model:
         return model_fields
 
     @classmethod
-    def get_constraints(cls) -> dict[str, fields.RelatedField]:
+    def get_constraints(cls) -> dict[str, 'fields.RelatedField']:
         model_fields = {}
 
         for name, attr in cls.__dict__.items():
+            from jija_orm import fields
             if isinstance(attr, fields.RelatedField):
                 model_fields[name] = attr
 
@@ -55,6 +62,9 @@ class Model:
         return model_fields
 
     async def save(self):
+        # if self.__state['id'] is None:
+        #     return await self.insert()
+
         to_update = {}
         for arg in self.__state:
             real_arg = getattr(self, arg)
@@ -92,8 +102,19 @@ class Model:
     def multiple_create(cls, rows):
         return cls.manager.multiple_insert(rows)
 
-    def __await__(self):
-        return self.manager.insert(self.__state)
+    @classmethod
+    def insert(cls, **kwargs):
+        return cls.manager.insert(**kwargs)
 
     def __repr__(self):
         return f'<{self.__class__.__name__} {self.id}>'
+
+    def __eq__(self, other: 'Model'):
+        if type(self) != type(other):
+            raise TypeError(f'Cant compare different types {type(self)} and {type(other)}')
+
+        for item in self.__state:
+            if getattr(other, item, None) != self.__state[item]:
+                return False
+
+        return True
